@@ -1,12 +1,12 @@
-import sys
 import threading
 import time
 import warnings
+from concurrent.futures import Future
 from unittest.mock import patch
 
 import dask.array as da
 import pytest
-from qtpy.QtCore import Qt
+from qtpy.QtCore import Qt, QThread
 from qtpy.QtWidgets import QPushButton
 
 from napari._qt.dialogs.qt_notification import NapariQtNotification
@@ -17,8 +17,6 @@ from napari.utils.notifications import (
     notification_manager,
 )
 
-PY37_OR_LOWER = sys.version_info[:2] <= (3, 7)
-
 
 def _threading_warn():
     thr = threading.Thread(target=_warn)
@@ -88,9 +86,38 @@ def test_notification_manager_via_gui(
             notification_manager.records = []
 
 
+@patch('napari._qt.dialogs.qt_notification.QDialog.show')
+def test_show_notification_from_thread(mock_show, monkeypatch, qtbot):
+    from napari.settings import get_settings
+
+    settings = get_settings()
+
+    monkeypatch.setattr(
+        settings.application,
+        'gui_notification_level',
+        NotificationSeverity.INFO,
+    )
+
+    class CustomThread(QThread):
+        def run(self):
+            notif = Notification(
+                'hi',
+                NotificationSeverity.INFO,
+                actions=[('click', lambda x: None)],
+            )
+            res = NapariQtNotification.show_notification(notif)
+            assert isinstance(res, Future)
+            assert res.result() is None
+            mock_show.assert_called_once()
+
+    thread = CustomThread()
+    with qtbot.waitSignal(thread.finished):
+        thread.start()
+
+
 @pytest.mark.parametrize('severity', NotificationSeverity.__members__)
 @patch('napari._qt.dialogs.qt_notification.QDialog.show')
-def test_notification_display(mock_show, severity, monkeypatch):
+def test_notification_display(mock_show, severity, monkeypatch, qtbot):
     """Test that NapariQtNotification can present a Notification event.
 
     NOTE: in napari.utils._tests.test_notification_manager, we already test
@@ -103,10 +130,16 @@ def test_notification_display(mock_show, severity, monkeypatch):
     that show_notification is capable of receiving various event types.
     (we don't need to test that )
     """
-    from napari.utils.settings import SETTINGS
+    from napari.settings import get_settings
+
+    settings = get_settings()
 
     monkeypatch.delenv('NAPARI_CATCH_ERRORS', raising=False)
-    monkeypatch.setattr(SETTINGS.application, 'gui_notification_level', 'info')
+    monkeypatch.setattr(
+        settings.application,
+        'gui_notification_level',
+        NotificationSeverity.INFO,
+    )
     notif = Notification('hi', severity, actions=[('click', lambda x: None)])
     NapariQtNotification.show_notification(notif)
     if NotificationSeverity(severity) >= NotificationSeverity.INFO:
@@ -121,14 +154,21 @@ def test_notification_display(mock_show, severity, monkeypatch):
     dialog.toggle_expansion()
     assert not dialog.property('expanded')
     dialog.close()
+    dialog.deleteLater()
 
 
 @patch('napari._qt.dialogs.qt_notification.QDialog.show')
 def test_notification_error(mock_show, monkeypatch, clean_current):
-    from napari.utils.settings import SETTINGS
+    from napari.settings import get_settings
+
+    settings = get_settings()
 
     monkeypatch.delenv('NAPARI_CATCH_ERRORS', raising=False)
-    monkeypatch.setattr(SETTINGS.application, 'gui_notification_level', 'info')
+    monkeypatch.setattr(
+        settings.application,
+        'gui_notification_level',
+        NotificationSeverity.INFO,
+    )
     try:
         raise ValueError('error!')
     except ValueError as e:
@@ -142,14 +182,14 @@ def test_notification_error(mock_show, monkeypatch, clean_current):
     mock_show.assert_called_once()
 
 
-@pytest.mark.skipif(PY37_OR_LOWER, reason="Fails on py37")
+@pytest.mark.sync_only
 def test_notifications_error_with_threading(make_napari_viewer):
     """Test notifications of `threading` threads, using a dask example."""
-    random_image = da.random.random(size=(50, 50))
+    random_image = da.random.random((50, 50))
     with notification_manager:
         viewer = make_napari_viewer()
         viewer.add_image(random_image)
-        result = da.divide(random_image, da.zeros(50, 50))
+        result = da.divide(random_image, da.zeros((50, 50)))
         viewer.add_image(result)
         assert len(notification_manager.records) >= 1
         notification_manager.records = []
