@@ -1,13 +1,24 @@
 from qtpy.QtCore import Qt
-from qtpy.QtWidgets import QComboBox, QHBoxLayout, QLabel, QSlider
+from qtpy.QtWidgets import (
+    QComboBox,
+    QHBoxLayout,
+    QLabel,
+    QPushButton,
+    QSlider,
+    QWidget,
+)
+from superqt import QLabeledDoubleSlider
 
 from ...layers.image._image_constants import (
     ImageRendering,
     Interpolation,
     Interpolation3D,
+    VolumeDepiction,
 )
+from ...utils.action_manager import action_manager
 from ...utils.translations import trans
 from .qt_image_controls_base import QtBaseImageControls
+from .qt_layer_controls_base import LayerListGridLayout
 
 
 class QtImageControls(QtBaseImageControls):
@@ -50,6 +61,10 @@ class QtImageControls(QtBaseImageControls):
         self.layer.events.iso_threshold.connect(self._on_iso_threshold_change)
         self.layer.events.attenuation.connect(self._on_attenuation_change)
         self.layer.events._ndisplay.connect(self._on_ndisplay_change)
+        self.layer.events.depiction.connect(self._on_depiction_change)
+        self.layer.plane.events.thickness.connect(
+            self._on_plane_thickness_change
+        )
 
         self.interpComboBox = QComboBox(self)
         self.interpComboBox.activated[str].connect(self.changeInterpolation)
@@ -66,6 +81,40 @@ class QtImageControls(QtBaseImageControls):
         self.renderComboBox = renderComboBox
         self.renderLabel = QLabel(trans._('rendering:'))
 
+        self.depictionComboBox = QComboBox(self)
+        depiction_options = [d.value for d in VolumeDepiction]
+        self.depictionComboBox.addItems(depiction_options)
+        index = self.depictionComboBox.findText(
+            self.layer.depiction, Qt.MatchFixedString
+        )
+        self.depictionComboBox.setCurrentIndex(index)
+        self.depictionComboBox.activated[str].connect(self.changeDepiction)
+        self.depictionLabel = QLabel(trans._('depiction:'))
+
+        self.planeControls = QtPlaneControls()
+        self.planeControls.planeThicknessSlider.setValue(
+            self.layer.plane.thickness
+        )
+        self.planeControls.planeThicknessSlider.valueChanged.connect(
+            self.changePlaneThickness
+        )
+        action_manager.bind_button(
+            'napari:orient_plane_normal_along_z',
+            self.planeControls.planeNormalButtons.zButton,
+        )
+        action_manager.bind_button(
+            'napari:orient_plane_normal_along_y',
+            self.planeControls.planeNormalButtons.yButton,
+        )
+        action_manager.bind_button(
+            'napari:orient_plane_normal_along_x',
+            self.planeControls.planeNormalButtons.xButton,
+        )
+        action_manager.bind_button(
+            'napari:orient_plane_normal_along_view_direction',
+            self.planeControls.planeNormalButtons.obliqueButton,
+        )
+
         sld = QSlider(Qt.Horizontal, parent=self)
         sld.setFocusPolicy(Qt.NoFocus)
         sld.setMinimum(0)
@@ -115,11 +164,14 @@ class QtImageControls(QtBaseImageControls):
         self.grid_layout.addWidget(self.interpComboBox, 6, 1)
         self.grid_layout.addWidget(self.renderLabel, 7, 0)
         self.grid_layout.addWidget(self.renderComboBox, 7, 1)
-        self.grid_layout.addWidget(self.isoThresholdLabel, 8, 0)
-        self.grid_layout.addWidget(self.isoThresholdSlider, 8, 1)
-        self.grid_layout.addWidget(self.attenuationLabel, 9, 0)
-        self.grid_layout.addWidget(self.attenuationSlider, 9, 1)
-        self.grid_layout.setRowStretch(9, 1)
+        self.grid_layout.addWidget(self.depictionLabel, 8, 0)
+        self.grid_layout.addWidget(self.depictionComboBox, 8, 1)
+        self.grid_layout.addWidget(self.planeControls, 9, 0, 2, 2)
+        self.grid_layout.addWidget(self.isoThresholdLabel, 11, 0)
+        self.grid_layout.addWidget(self.isoThresholdSlider, 11, 1)
+        self.grid_layout.addWidget(self.attenuationLabel, 12, 0)
+        self.grid_layout.addWidget(self.attenuationSlider, 12, 1)
+        self.grid_layout.setRowStretch(13, 1)
         self.grid_layout.setColumnStretch(1, 1)
         self.grid_layout.setSpacing(4)
 
@@ -163,6 +215,13 @@ class QtImageControls(QtBaseImageControls):
         self.layer.rendering = text
         self._toggle_rendering_parameter_visbility()
 
+    def changeDepiction(self, text):
+        self.layer.depiction = text
+        self._toggle_plane_parameter_visibility()
+
+    def changePlaneThickness(self, value: float):
+        self.layer.plane.thickness = value
+
     def changeIsoThreshold(self, value):
         """Change isosurface threshold on the layer model.
 
@@ -221,6 +280,21 @@ class QtImageControls(QtBaseImageControls):
             self.renderComboBox.setCurrentIndex(index)
             self._toggle_rendering_parameter_visbility()
 
+    def _on_depiction_change(self):
+        """Receive layer model depiction change event and update combobox."""
+        with self.layer.events.depiction.blocker():
+            index = self.depictionComboBox.findText(
+                self.layer.depiction, Qt.MatchFixedString
+            )
+            self.depictionComboBox.setCurrentIndex(index)
+            self._toggle_plane_parameter_visibility()
+
+    def _on_plane_thickness_change(self):
+        with self.layer.plane.events.blocker():
+            self.planeControls.planeThicknessSlider.setValue(
+                self.layer.plane.thickness
+            )
+
     def _toggle_rendering_parameter_visbility(self):
         """Hide isosurface rendering parameters if they aren't needed."""
         rendering = ImageRendering(self.layer.rendering)
@@ -237,6 +311,14 @@ class QtImageControls(QtBaseImageControls):
             self.attenuationSlider.hide()
             self.attenuationLabel.hide()
 
+    def _toggle_plane_parameter_visibility(self):
+        """Hide plane rendering controls if they aren't needed."""
+        depiction = VolumeDepiction(self.layer.depiction)
+        if depiction == VolumeDepiction.VOLUME or self.layer._ndisplay == 2:
+            self.planeControls.hide()
+        if depiction == VolumeDepiction.PLANE and self.layer._ndisplay == 3:
+            self.planeControls.show()
+
     def _update_interpolation_combo(self):
         self.interpComboBox.clear()
         interp_names = (
@@ -253,6 +335,7 @@ class QtImageControls(QtBaseImageControls):
     def _on_ndisplay_change(self):
         """Toggle between 2D and 3D visualization modes."""
         self._update_interpolation_combo()
+        self._toggle_plane_parameter_visibility()
         if self.layer._ndisplay == 2:
             self.isoThresholdSlider.hide()
             self.isoThresholdLabel.hide()
@@ -260,7 +343,66 @@ class QtImageControls(QtBaseImageControls):
             self.attenuationLabel.hide()
             self.renderComboBox.hide()
             self.renderLabel.hide()
+            self.depictionComboBox.hide()
+            self.depictionLabel.hide()
         else:
             self.renderComboBox.show()
             self.renderLabel.show()
             self._toggle_rendering_parameter_visbility()
+            self.depictionComboBox.show()
+            self.depictionLabel.show()
+
+
+class PlaneNormalButtons(QWidget):
+    """Qt buttons for controlling plane orientation.
+
+        Attributes
+    ----------
+    xButton : qtpy.QtWidgets.QPushButton
+        Button which orients a plane normal along the x axis.
+    yButton : qtpy.QtWidgets.QPushButton
+        Button which orients a plane normal along the y axis.
+    zButton : qtpy.QtWidgets.QPushButton
+        Button which orients a plane normal along the z axis.
+    obliqueButton : qtpy.QtWidgets.QPushButton
+        Button which orients a plane normal along the camera view direction.
+    """
+
+    def __init__(self, parent=None) -> None:
+        super().__init__(parent=parent)
+        self.setLayout(QHBoxLayout())
+        self.layout().setSpacing(2)
+        self.layout().setContentsMargins(0, 0, 0, 0)
+
+        self.xButton = QPushButton('x')
+        self.yButton = QPushButton('y')
+        self.zButton = QPushButton('z')
+        self.obliqueButton = QPushButton(trans._('oblique'))
+
+        self.layout().addWidget(self.xButton)
+        self.layout().addWidget(self.yButton)
+        self.layout().addWidget(self.zButton)
+        self.layout().addWidget(self.obliqueButton)
+
+
+class QtPlaneControls(QWidget):
+    """Qt widget encapsulating plane controls for an image layer."""
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.grid_layout = LayerListGridLayout(self)
+        self.setLayout(self.grid_layout)
+
+        self.planeNormalLabel = QLabel(trans._('plane normal:'))
+        self.planeNormalButtons = PlaneNormalButtons(parent=self)
+
+        self.planeThicknessSlider = QLabeledDoubleSlider(Qt.Horizontal, self)
+        self.planeThicknessSlider.setFocusPolicy(Qt.NoFocus)
+        self.planeThicknessSlider.setMinimum(1)
+        self.planeThicknessSlider.setMaximum(50)
+        self.planeThicknessLabel = QLabel(trans._('plane thickness:'))
+
+        self.grid_layout.addWidget(self.planeNormalLabel, 1, 0)
+        self.grid_layout.addWidget(self.planeNormalButtons, 1, 1)
+        self.grid_layout.addWidget(self.planeThicknessLabel, 2, 0)
+        self.grid_layout.addWidget(self.planeThicknessSlider, 2, 1)
