@@ -93,7 +93,7 @@ class QtBaseImageControls(QtLayerControls):
             self.layer.contrast_limits_range, self.layer.dtype
         )
         self.contrastLimitsSlider.setRange(*self.layer.contrast_limits_range)
-        self.contrastLimitsSlider.setSingleStep(10 ** -decimals)
+        self.contrastLimitsSlider.setSingleStep(10**-decimals)
         self.contrastLimitsSlider.setValue(self.layer.contrast_limits)
         self.contrastLimitsSlider.setToolTip(
             trans._('Right click for detailed slider popup.')
@@ -206,12 +206,16 @@ class AutoScaleButtons(QWidget):
         auto_btn.setFocusPolicy(Qt.NoFocus)
         once_btn.clicked.connect(lambda: auto_btn.setChecked(False))
         connect_no_arg(once_btn.clicked, layer, "reset_contrast_limits")
-        connect_setattr(auto_btn.toggled, layer, "_keep_autoscale")
+        connect_setattr(auto_btn.toggled, layer, "_keep_auto_contrast")
         connect_no_arg(auto_btn.clicked, layer, "reset_contrast_limits")
 
         self.layout().addWidget(once_btn)
         self.layout().addWidget(auto_btn)
 
+        # just for testing
+        self._once_btn = once_btn
+        self._auto_btn = auto_btn
+
 
 class QContrastLimitsPopup(QRangeSliderPopup):
     def __init__(self, layer: Image, parent=None):
@@ -220,7 +224,7 @@ class QContrastLimitsPopup(QRangeSliderPopup):
         decimals = range_to_decimals(layer.contrast_limits_range, layer.dtype)
         self.slider.setRange(*layer.contrast_limits_range)
         self.slider.setDecimals(decimals)
-        self.slider.setSingleStep(10 ** -decimals)
+        self.slider.setSingleStep(10**-decimals)
         self.slider.setValue(layer.contrast_limits)
 
         connect_setattr(self.slider.valueChanged, layer, "contrast_limits")
@@ -235,7 +239,7 @@ class QContrastLimitsPopup(QRangeSliderPopup):
         reset_btn = QPushButton("reset")
         reset_btn.setObjectName("reset_clims_button")
         reset_btn.setToolTip(trans._("autoscale contrast to data range"))
-        reset_btn.setFixedWidth(40)
+        reset_btn.setFixedWidth(45)
         reset_btn.clicked.connect(reset)
         self._layout.addWidget(reset_btn, alignment=Qt.AlignBottom)
 
@@ -248,7 +252,7 @@ class QContrastLimitsPopup(QRangeSliderPopup):
             range_btn.setToolTip(
                 trans._("set contrast range to full bit-depth")
             )
-            range_btn.setFixedWidth(65)
+            range_btn.setFixedWidth(75)
             range_btn.clicked.connect(layer.reset_contrast_limits_range)
             self._layout.addWidget(range_btn, alignment=Qt.AlignBottom)
 
