@@ -52,7 +52,7 @@ class QColoredSVGIcon(QIcon):
         colorized = get_colorized_svg(path_or_xml, color, opacity)
         super().__init__(SVGBufferIconEngine(colorized))
 
-    @lru_cache()
+    @lru_cache
     def colored(
         self,
         color: Optional[str] = None,
@@ -88,7 +88,7 @@ class QColoredSVGIcon(QIcon):
         return QColoredSVGIcon(self._svg, color, opacity)
 
     @staticmethod
-    @lru_cache()
+    @lru_cache
     def from_resources(
         icon_name: str,
     ) -> 'QColoredSVGIcon':
