@@ -5,7 +5,7 @@ from vispy.color import Colormap as VispyColormap
 from vispy.scene.node import Node
 
 from ...utils.translations import trans
-from ..utils.gl import fix_data_dtype
+from ..utils.gl import fix_data_dtype, get_gl_extensions
 from ..visuals.image import Image as ImageNode
 from ..visuals.volume import Volume as VolumeNode
 from .base import VispyBaseLayer
@@ -13,6 +13,15 @@ from .base import VispyBaseLayer
 
 class ImageLayerNode:
     def __init__(self, custom_node: Node = None, texture_format=None):
+        if (
+            texture_format == 'auto'
+            and 'texture_float' not in get_gl_extensions()
+        ):
+            # if the GPU doesn't support float textures, texture_format auto
+            # WILL fail on float dtypes
+            # https://github.com/napari/napari/issues/3988
+            texture_format = None
+
         self._custom_node = custom_node
         self._image_node = ImageNode(
             None,
@@ -49,6 +58,7 @@ class VispyImageLayer(VispyBaseLayer):
         self._array_like = True
 
         self.layer.events.rendering.connect(self._on_rendering_change)
+        self.layer.events.depiction.connect(self._on_depiction_change)
         self.layer.events.interpolation.connect(self._on_interpolation_change)
         self.layer.events.colormap.connect(self._on_colormap_change)
         self.layer.events.contrast_limits.connect(
@@ -57,18 +67,13 @@ class VispyImageLayer(VispyBaseLayer):
         self.layer.events.gamma.connect(self._on_gamma_change)
         self.layer.events.iso_threshold.connect(self._on_iso_threshold_change)
         self.layer.events.attenuation.connect(self._on_attenuation_change)
-        self.layer.experimental_slicing_plane.events.enabled.connect(
-            self._on_experimental_slicing_plane_enabled_change
+        self.layer.plane.events.position.connect(
+            self._on_plane_position_change
         )
-        self.layer.experimental_slicing_plane.events.position.connect(
-            self._on_experimental_slicing_plane_position_change
-        )
-        self.layer.experimental_slicing_plane.events.thickness.connect(
-            self._on_experimental_slicing_plane_thickness_change
-        )
-        self.layer.experimental_slicing_plane.events.normal.connect(
-            self._on_experimental_slicing_plane_normal_change
+        self.layer.plane.events.thickness.connect(
+            self._on_plane_thickness_change
         )
+        self.layer.plane.events.normal.connect(self._on_plane_normal_change)
 
         # display_change is special (like data_change) because it requires a self.reset()
         # this means that we have to call it manually. Also, it must be called before reset
@@ -148,6 +153,10 @@ class VispyImageLayer(VispyBaseLayer):
             self._on_attenuation_change()
             self._on_iso_threshold_change()
 
+    def _on_depiction_change(self):
+        if isinstance(self.node, VolumeNode):
+            self.node.raycasting_mode = str(self.layer.depiction)
+
     def _on_colormap_change(self):
         self.node.cmap = VispyColormap(*self.layer.colormap)
 
@@ -166,31 +175,17 @@ class VispyImageLayer(VispyBaseLayer):
         if isinstance(self.node, VolumeNode):
             self.node.attenuation = self.layer.attenuation
 
-    def _on_experimental_slicing_plane_enabled_change(self):
+    def _on_plane_thickness_change(self):
         if isinstance(self.node, VolumeNode):
-            if self.layer.experimental_slicing_plane.enabled is True:
-                raycasting_mode = 'plane'
-            else:
-                raycasting_mode = 'volume'
-            self.node.raycasting_mode = raycasting_mode
+            self.node.plane_thickness = self.layer.plane.thickness
 
-    def _on_experimental_slicing_plane_thickness_change(self):
+    def _on_plane_position_change(self):
         if isinstance(self.node, VolumeNode):
-            self.node.plane_thickness = (
-                self.layer.experimental_slicing_plane.thickness
-            )
+            self.node.plane_position = self.layer.plane.position
 
-    def _on_experimental_slicing_plane_position_change(self):
+    def _on_plane_normal_change(self):
         if isinstance(self.node, VolumeNode):
-            self.node.plane_position = (
-                self.layer.experimental_slicing_plane.position
-            )
-
-    def _on_experimental_slicing_plane_normal_change(self):
-        if isinstance(self.node, VolumeNode):
-            self.node.plane_normal = (
-                self.layer.experimental_slicing_plane.normal
-            )
+            self.node.plane_normal = self.layer.plane.normal
 
     def reset(self, event=None):
         super().reset()
@@ -199,10 +194,10 @@ class VispyImageLayer(VispyBaseLayer):
         self._on_contrast_limits_change()
         self._on_gamma_change()
         self._on_rendering_change()
-        self._on_experimental_slicing_plane_enabled_change()
-        self._on_experimental_slicing_plane_position_change()
-        self._on_experimental_slicing_plane_normal_change()
-        self._on_experimental_slicing_plane_thickness_change()
+        self._on_depiction_change()
+        self._on_plane_position_change()
+        self._on_plane_normal_change()
+        self._on_plane_thickness_change()
 
     def downsample_texture(self, data, MAX_TEXTURE_SIZE):
         """Downsample data based on maximum allowed texture size.
