@@ -1,5 +1,6 @@
 import numpy as np
 
+from ....utils.translations import trans
 from .._shapes_utils import (
     center_radii_to_corners,
     rectangle_to_box,
@@ -17,7 +18,7 @@ class Ellipse(Shape):
     data : (4, D) array or (2, 2) array.
         Either a (2, 2) array specifying the center and radii of an axis
         aligned ellipse, or a (4, D) array specifying the four corners of a
-        boudning box that contains the ellipse. These need not be axis aligned.
+        bounding box that contains the ellipse. These need not be axis aligned.
     edge_width : float
         thickness of lines and edges.
     opacity : float
@@ -54,8 +55,7 @@ class Ellipse(Shape):
 
     @property
     def data(self):
-        """(4, D) array: ellipse vertices.
-        """
+        """(4, D) array: ellipse vertices."""
         return self._data
 
     @data.setter
@@ -70,9 +70,11 @@ class Ellipse(Shape):
 
         if len(data) != 4:
             raise ValueError(
-                f"""Data shape does not match a ellipse.
-                             Ellipse expects four corner vertices,
-                             {len(data)} provided."""
+                trans._(
+                    "Data shape does not match a ellipse. Ellipse expects four corner vertices, {number} provided.",
+                    deferred=True,
+                    number=len(data),
+                )
             )
 
         self._data = data
