@@ -1,13 +1,14 @@
 from abc import ABC, abstractmethod
-import numpy as np
-from copy import copy
 
+import numpy as np
+
+from ....utils.translations import trans
 from .._shapes_utils import (
+    is_collinear,
+    path_to_mask,
+    poly_to_mask,
     triangulate_edge,
     triangulate_face,
-    is_collinear,
-    poly_to_mask,
-    path_to_mask,
 )
 
 
@@ -55,8 +56,8 @@ class Shape(ABC):
         Min and max values of the M non-displayed dimensions, useful for
         slicing multidimensional shapes.
 
-    Extended Summary
-    ----------
+    Notes
+    -----
     _closed : bool
         Bool if shape edge is a closed path or not
     _box : np.ndarray
@@ -169,8 +170,7 @@ class Shape(ABC):
 
     @property
     def edge_width(self):
-        """float: thickness of lines and edges.
-        """
+        """float: thickness of lines and edges."""
         return self._edge_width
 
     @edge_width.setter
@@ -342,8 +342,10 @@ class Shape(ABC):
             transform = np.array([[-1, 0], [0, 1]])
         else:
             raise ValueError(
-                """Axis not recognized, must be one of "{0, 1}"
-                             """
+                trans._(
+                    'Axis not recognized, must be one of "{{0, 1}}"',
+                    deferred=True,
+                )
             )
         if center is None:
             self.transform(transform)
@@ -390,9 +392,12 @@ class Shape(ABC):
             shape_plane = [mask_shape[d] for d in self.dims_displayed]
         else:
             raise ValueError(
-                f"""mask shape length must either be 2 or the same
-            as the dimensionality of the shape, expected {self.data.shape[1]}
-            got {len(mask_shape)}."""
+                trans._(
+                    "mask shape length must either be 2 or the same as the dimensionality of the shape, expected {expected} got {received}.",
+                    deferred=True,
+                    expected=self.data.shape[1],
+                    received=len(mask_shape),
+                )
             )
 
         if self._use_face_vertices:
@@ -421,9 +426,10 @@ class Shape(ABC):
                         self.slice_key[0, j], self.slice_key[1, j] + 1
                     )
                 j += 1
-            displayed_order = np.array(copy(self.dims_displayed))
-            displayed_order[np.argsort(displayed_order)] = list(
-                range(len(displayed_order))
+            # equivalent to: displayed_order = np.argsort(self.dims_displayed)
+            dims_displayed = self.dims_displayed
+            displayed_order = sorted(
+                range(len(dims_displayed)), key=lambda x: dims_displayed[x]
             )
             mask[tuple(slice_key)] = mask_p.transpose(displayed_order)
         else:
