@@ -4,13 +4,14 @@ that match the plugin naming convention, and retrieving related metadata.
 """
 import json
 import re
-import ssl
 from concurrent.futures import ThreadPoolExecutor, as_completed
-from functools import lru_cache, partial
-from typing import Dict, Generator, List, NamedTuple, Optional
+from functools import lru_cache
+from typing import Dict, Generator, List, Optional, Tuple
 from urllib import error, parse, request
 
-import certifi
+from npe2.manifest.package_metadata import PackageMetadata
+
+from .utils import normalized_name
 
 PYPI_SIMPLE_API_URL = 'https://pypi.org/simple/'
 
@@ -21,20 +22,6 @@ setup_py_pypi_name = re.compile(
     r"setup\s?\(.*name\s?=\s?['\"]([^'\"]+)['\"]", re.DOTALL
 )
 
-context = ssl.create_default_context(cafile=certifi.where())
-urlopen = partial(request.urlopen, context=context)
-
-
-class ProjectInfo(NamedTuple):
-    """Info associated with a PyPI Project."""
-
-    name: str
-    version: str
-    url: str
-    summary: str
-    author: str
-    license: str
-
 
 @lru_cache(maxsize=128)
 def get_packages_by_prefix(prefix: str) -> Dict[str, str]:
@@ -50,7 +37,7 @@ def get_packages_by_prefix(prefix: str) -> Dict[str, str]:
         {name: url} for all packages at pypi that start with ``prefix``
     """
 
-    with urlopen(PYPI_SIMPLE_API_URL) as response:
+    with request.urlopen(PYPI_SIMPLE_API_URL) as response:
         html = response.read().decode()
 
     return {
@@ -76,7 +63,7 @@ def get_packages_by_classifier(classifier: str) -> List[str]:
     url = f"https://pypi.org/search/?c={parse.quote_plus(classifier)}&page="
     while True:
         try:
-            with urlopen(f'{url}{page}') as response:
+            with request.urlopen(f'{url}{page}') as response:
                 html = response.read().decode()
                 packages.extend(pattern.findall(html))
             page += 1
@@ -99,7 +86,7 @@ def get_package_versions(name: str) -> List[str]:
     tuple
         versions available on pypi
     """
-    with urlopen(PYPI_SIMPLE_API_URL + name) as response:
+    with request.urlopen(PYPI_SIMPLE_API_URL + name) as response:
         html = response.read()
 
     return re.findall(f'>{name}-(.+).tar', html.decode())
@@ -108,10 +95,10 @@ def get_package_versions(name: str) -> List[str]:
 @lru_cache(maxsize=128)
 def ensure_published_at_pypi(
     name: str, min_dev_status=3
-) -> Optional[ProjectInfo]:
+) -> Optional[PackageMetadata]:
     """Return name if ``name`` is a package in PyPI with dev_status > min."""
     try:
-        with urlopen(f'https://pypi.org/pypi/{name}/json') as resp:
+        with request.urlopen(f'https://pypi.org/pypi/{name}/json') as resp:
             info = json.loads(resp.read().decode()).get("info")
     except error.HTTPError:
         return None
@@ -120,11 +107,12 @@ def ensure_published_at_pypi(
         if any(f'Development Status :: {1}' in x for x in classifiers):
             return None
 
-    return ProjectInfo(
+    return PackageMetadata(
+        metadata_version="1.0",
         name=normalized_name(info["name"]),
         version=info["version"],
-        url=info["home_page"],
         summary=info["summary"],
+        home_page=info["home_page"],
         author=info["author"],
         license=info["license"] or "UNKNOWN",
     )
@@ -132,14 +120,14 @@ def ensure_published_at_pypi(
 
 def iter_napari_plugin_info(
     skip={'napari-plugin-engine'},
-) -> Generator[ProjectInfo, None, None]:
+) -> Generator[Tuple[Optional[PackageMetadata], bool], None, None]:
     """Return a generator that yields ProjectInfo of available napari plugins.
 
     By default, requires that packages are at least "Alpha" stage of
     development.  to allow lower, change the ``min_dev_status`` argument to
     ``ensure_published_at_pypi``.
     """
-    already_yielded = set()
+    already_yielded = []
     with ThreadPoolExecutor(max_workers=8) as executor:
         futures = [
             executor.submit(ensure_published_at_pypi, name)
@@ -150,9 +138,6 @@ def iter_napari_plugin_info(
         for future in as_completed(futures):
             info = future.result()
             if info and info not in already_yielded:
-                already_yielded.add(info)
-                yield info
-
-
-def normalized_name(name) -> str:
-    return re.sub(r"[-_.]+", "-", name).lower()
+                already_yielded.append(info)
+                # `False` To match hub API on conda-forge availability
+                yield (info, True)
