@@ -1,3 +1,4 @@
+import re
 from typing import Dict
 
 from . import _npe2, plugin_manager
@@ -36,3 +37,11 @@ def get_potential_readers(filename: str) -> Dict[str, str]:
         del readers['builtins']
 
     return readers
+
+
+def normalized_name(name: str) -> str:
+    """
+    Normalize a plugin name by replacing underscores and dots by dashes and
+    lower casing it.
+    """
+    return re.sub(r"[-_.]+", "-", name).lower()
