@@ -9,6 +9,7 @@ from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Tuple, cast
 from warnings import warn
 
 from pydantic import BaseModel, BaseSettings, ValidationError
+from pydantic.env_settings import SettingsError
 from pydantic.error_wrappers import display_errors
 
 from ..utils.events import EmitterGroup, EventedModel
@@ -298,6 +299,19 @@ def nested_env_settings(
                         if env_val is not None:
                             break
 
+                is_complex, all_json_fail = super_eset.field_is_complex(subf)
+                if env_val is not None and is_complex:
+                    try:
+                        env_val = settings.__config__.json_loads(env_val)
+                    except ValueError as e:
+                        if not all_json_fail:
+                            msg = f'error parsing JSON for "{env_name}"'
+                            raise SettingsError(msg) from e
+
+                    if isinstance(env_val, dict):
+                        explode = super_eset.explode_env_vars(field, env_vars)
+                        env_val = deep_update(env_val, explode)
+
                 # if we found an env var, store it and return it
                 if env_val is not None:
                     if field.alias not in d:
