@@ -2,13 +2,14 @@
 """
 import builtins
 import collections.abc
+import importlib.metadata
 import inspect
 import itertools
 import os
 import re
 import sys
 from enum import Enum, EnumMeta
-from os import PathLike, fspath
+from os import fspath
 from os import path as os_path
 from pathlib import Path
 from typing import (
@@ -17,7 +18,6 @@ from typing import (
     Callable,
     Iterable,
     Optional,
-    Sequence,
     Type,
     TypeVar,
     Union,
@@ -33,11 +33,6 @@ if TYPE_CHECKING:
 
 ROOT_DIR = os_path.dirname(os_path.dirname(__file__))
 
-try:
-    from importlib import metadata as importlib_metadata
-except ImportError:
-    import importlib_metadata  # noqa
-
 
 def parse_version(v) -> 'packaging.version._BaseVersion':
     """Parse a version string and return a packaging.version.Version obj."""
@@ -50,25 +45,34 @@ def parse_version(v) -> 'packaging.version._BaseVersion':
 
 
 def running_as_bundled_app() -> bool:
-    """Infer whether we are running as a briefcase bundle"""
+    """Infer whether we are running as a briefcase bundle."""
     # https://github.com/beeware/briefcase/issues/412
     # https://github.com/beeware/briefcase/pull/425
     # note that a module may not have a __package__ attribute
     # From 0.4.12 we add a sentinel file next to the bundled sys.executable
     if (Path(sys.executable).parent / ".napari_is_bundled").exists():
         return True
+
     try:
         app_module = sys.modules['__main__'].__package__
     except AttributeError:
         return False
+
     try:
-        metadata = importlib_metadata.metadata(app_module)
-    except importlib_metadata.PackageNotFoundError:
+        metadata = importlib.metadata.metadata(app_module)
+    except importlib.metadata.PackageNotFoundError:
         return False
 
     return 'Briefcase-Version' in metadata
 
 
+def running_as_constructor_app() -> bool:
+    """Infer whether we are running as a constructor bundle."""
+    return (
+        Path(sys.prefix).parent.parent / ".napari_is_bundled_constructor"
+    ).exists()
+
+
 def bundle_bin_dir() -> Optional[str]:
     """Return path to briefcase app_packages/bin if it exists."""
     bin = os_path.join(os_path.dirname(sys.exec_prefix), 'app_packages', 'bin')
@@ -325,7 +329,7 @@ def camel_to_spaces(val):
     return camel_to_spaces_pattern.sub(r" \1", val)
 
 
-T = TypeVar('T', str, Sequence[str])
+T = TypeVar('T', str, Path)
 
 
 def abspath_or_url(relpath: T, *, must_exist: bool = False) -> T:
@@ -336,49 +340,40 @@ def abspath_or_url(relpath: T, *, must_exist: bool = False) -> T:
 
     Parameters
     ----------
-    relpath : str or list or tuple
-        A path, or list or tuple of paths.
+    relpath : str|Path
+        A path, either as string or Path object.
     must_exist : bool, default True
         Raise ValueError if `relpath` is not a URL and does not exist.
 
     Returns
     -------
-    abspath : str or list or tuple
+    abspath : str|Path
         An absolute path, or list or tuple of absolute paths (same type as
-        input).
+        input)
     """
     from urllib.parse import urlparse
 
-    if isinstance(relpath, (tuple, list)):
-        return type(relpath)(
-            abspath_or_url(p, must_exist=must_exist) for p in relpath
+    if not isinstance(relpath, (str, Path)):
+        raise TypeError(
+            trans._("Argument must be a string or Path", deferred=True)
         )
+    OriginType = type(relpath)
 
-    if isinstance(relpath, (str, PathLike)):
-        relpath = fspath(relpath)
-        urlp = urlparse(relpath)
-        if urlp.scheme and urlp.netloc:
-            return relpath
+    relpath = fspath(relpath)
+    urlp = urlparse(relpath)
+    if urlp.scheme and urlp.netloc:
+        return relpath
 
-        path = os_path.abspath(os_path.expanduser(relpath))
-        if must_exist and not (
-            urlp.scheme or urlp.netloc or os.path.exists(path)
-        ):
-            raise ValueError(
-                trans._(
-                    "Requested path {path!r} does not exist.",
-                    deferred=True,
-                    path=path,
-                )
+    path = os_path.abspath(os_path.expanduser(relpath))
+    if must_exist and not (urlp.scheme or urlp.netloc or os.path.exists(path)):
+        raise ValueError(
+            trans._(
+                "Requested path {path!r} does not exist.",
+                deferred=True,
+                path=path,
             )
-        return path
-
-    raise TypeError(
-        trans._(
-            "Argument must be a string, PathLike, or sequence thereof",
-            deferred=True,
         )
-    )
+    return OriginType(path)
 
 
 class CallDefault(inspect.Parameter):
