@@ -3,6 +3,8 @@
 All functions follow this pattern, (where <layer_type> is replaced with one
 of the layer types, like "image", "points", etc...):
 
+.. code-block:: python
+
     def view_<layer_type>(*args, **kwargs):
         # ... pop all of the viewer kwargs out of kwargs into viewer_kwargs
         viewer = Viewer(**viewer_kwargs)
@@ -14,6 +16,8 @@ import inspect
 
 from numpydoc.docscrape import NumpyDocString as _NumpyDocString
 
+from napari.components.dims import Dims
+
 from .viewer import Viewer
 
 __all__ = [
@@ -105,16 +109,23 @@ def _merge_layer_viewer_sigs_docs(func):
 
 
 _viewer_params = inspect.signature(Viewer).parameters
+_dims_params = inspect.signature(Dims).parameters
 
 
 def _make_viewer_then(add_method: str, args, kwargs) -> Viewer:
     """Utility function that creates a viewer, adds a layer, returns viewer."""
     vkwargs = {k: kwargs.pop(k) for k in list(kwargs) if k in _viewer_params}
+    # separate dims kwargs because we want to set those after adding data
+    dims_kwargs = {
+        k: vkwargs.pop(k) for k in list(vkwargs) if k in _dims_params
+    }
     viewer = Viewer(**vkwargs)
     if 'kwargs' in kwargs:
         kwargs.update(kwargs.pop("kwargs"))
     method = getattr(viewer, add_method)
     method(*args, **kwargs)
+    for arg_name, arg_val in dims_kwargs.items():
+        setattr(viewer.dims, arg_name, arg_val)
     return viewer
 
 
